SDL_image: rebuilt libpng dlls for windows from 1.6.53 version

From 0a96f2eb3bc85359aa8aa023c2b9add699a66123 Mon Sep 17 00:00:00 2001
From: Ozkan Sezer <[EMAIL REDACTED]>
Date: Tue, 9 Dec 2025 04:23:02 +0300
Subject: [PATCH] rebuilt libpng dlls for windows from 1.6.53 version

---
 VisualC/external/include/png.h                |  14 +++++++-------
 VisualC/external/include/pngconf.h            |   2 +-
 VisualC/external/include/pnglibconf.h         |   2 +-
 VisualC/external/optional/x64/libpng16-16.dll | Bin 247296 -> 247296 bytes
 VisualC/external/optional/x86/libpng16-16.dll | Bin 229888 -> 229888 bytes
 5 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/VisualC/external/include/pngconf.h b/VisualC/external/include/pngconf.h
index 76b5c20b..f4ff1920 100644
--- a/VisualC/external/include/pngconf.h
+++ b/VisualC/external/include/pngconf.h
@@ -1,6 +1,6 @@
 /* pngconf.h - machine-configurable file for libpng
  *
- * libpng version 1.6.52
+ * libpng version 1.6.53
  *
  * Copyright (c) 2018-2025 Cosmin Truta
  * Copyright (c) 1998-2002,2004,2006-2016,2018 Glenn Randers-Pehrson
diff --git a/VisualC/external/include/pnglibconf.h b/VisualC/external/include/pnglibconf.h
index 175f05f1..8cb36293 100644
--- a/VisualC/external/include/pnglibconf.h
+++ b/VisualC/external/include/pnglibconf.h
@@ -1,6 +1,6 @@
 /* pnglibconf.h - library build configuration */
 
-/* libpng version 1.6.52 */
+/* libpng version 1.6.53 */
 
 /* Copyright (c) 2018-2025 Cosmin Truta */
 /* Copyright (c) 1998-2002,2004,2006-2018 Glenn Randers-Pehrson */
diff --git a/VisualC/external/include/png.h b/VisualC/external/include/png.h
index bceb9aa4..bdcd243d 100644
--- a/VisualC/external/include/png.h
+++ b/VisualC/external/include/png.h
@@ -1,6 +1,6 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.6.52
+ * libpng version 1.6.53
  *
  * Copyright (c) 2018-2025 Cosmin Truta
  * Copyright (c) 1998-2002,2004,2006-2018 Glenn Randers-Pehrson
@@ -14,7 +14,7 @@
  *   libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.6.35, July 2018:
  *     Glenn Randers-Pehrson
  *   libpng versions 1.6.36, December 2018, through 1.6.52, December 2025:
  *     Cosmin Truta
  *   See also "Contributing Authors", below.
  */
@@ -238,7 +238,7 @@
  *    ...
  *    1.5.30                  15    10530  15.so.15.30[.0]
  *    ...
- *    1.6.52                  16    10651  16.so.16.52[.0]
+ *    1.6.53                  16    10651  16.so.16.53[.0]
  *
  *    Henceforth the source version will match the shared-library major and
  *    minor numbers; the shared-library major version number will be used for
@@ -274,7 +274,7 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.52"
+#define PNG_LIBPNG_VER_STRING "1.6.53"
 #define PNG_HEADER_VERSION_STRING " libpng version " PNG_LIBPNG_VER_STRING "\n"
 
 /* The versions of shared library builds should stay in sync, going forward */
@@ -285,7 +285,7 @@
 /* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
 #define PNG_LIBPNG_VER_MAJOR   1
 #define PNG_LIBPNG_VER_MINOR   6
-#define PNG_LIBPNG_VER_RELEASE 52
+#define PNG_LIBPNG_VER_RELEASE 53
 
 /* This should be zero for a public release, or non-zero for a
  * development version.
@@ -316,7 +316,7 @@
  * From version 1.0.1 it is:
  * XXYYZZ, where XX=major, YY=minor, ZZ=release
  */
-#define PNG_LIBPNG_VER 10652 /* 1.6.52 */
+#define PNG_LIBPNG_VER 10653 /* 1.6.53 */
 
 /* Library configuration: these options cannot be changed after
  * the library has been built.
@@ -426,7 +426,7 @@ extern "C" {
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef char* png_libpng_version_1_6_52;
+typedef char* png_libpng_version_1_6_53;
 
 /* Basic control structions.  Read libpng-manual.txt or libpng.3 for more info.
  *
@@ -14,7 +14,7 @@
  *   libpng versions 0.97, January 1998, through 1.6.35, July 2018:
  *     Glenn Randers-Pehrson
- *   libpng versions 1.6.36, December 2018, through 1.6.52, December 2025:
+ *   libpng versions 1.6.36, December 2018, through 1.6.53, December 2025:
  *     Cosmin Truta
  *   See also "Contributing Authors", below.
diff --git a/VisualC/external/optional/x64/libpng16-16.dll b/VisualC/external/optional/x64/libpng16-16.dll
index 6e13f6063631452b33fee8e84ff14d9581155a93..f60bc932a6f3425db1922fcdf2da7e43be1371b1 100644
GIT binary patch
delta 78
zcmZqZ;cw{SpKyc8L4V_|<8q91n-|HqFOp~6zDS;F&K5@F>GoHc<^idDSD0=w8gJiu
gm5EgbNbmp1WGx4zfAceQ_AvKUnr~;H!~9bd0M7g#DF6Tf

delta 78
zcmZqZ;cw{SpKyaop=jf+<8q91nit8pFOp~6zDS;F&K5?a>GoHc<^idDSD0=w8g1Ws
gm5EgbNbmp1WGx4zfAceQ_Ar<4GuX~Phxw-_0N8>aZvX%Q

diff --git a/VisualC/external/optional/x86/libpng16-16.dll b/VisualC/external/optional/x86/libpng16-16.dll
index 3ae111fdd5576ae84ac8b30e938515a53fee36c6..f78650251096d0ba45d12925d51a044f492bc9f4 100644
GIT binary patch
delta 79
zcmZo@;cIB&n{b1<=ri-i+s9-X=Qb~rYhNVCxP6fv)1Ix2#?#}kFwFu|zpgOdVl>`<
h^(s@OG?3Q+$aGx>NVD@X|Fvb_QenQG-G}+7DF7vEA94Ty

delta 79
zcmZo@;cIB&n{b2K)Qn~0?PIcxbD9^)wJ(xm+`dSTY0p+hqv`Qim}UW~UssrJF&b^Z
hdX*_s8c6GZWV$W`q}lnH|JpJ)?KRlW?!)}k6ae8>9)AD;